@@ -1,20 +1,20 @@
-import subprocess
-import re
-import os
-import sys
-
-os.chdir(os.path.dirname(os.path.abspath(__file__)))
-sys.path.insert(0, '../ceph')
-
-import ceph
-
+# coding=utf-8
 
 """
 Get ceph status from one node
 """
 
+import subprocess
+import re
+import os
+import sys
 
-class CephStatsCollector(ceph.CephCollector):
+sys.path.insert(0, os.path.join(os.path.dirname(os.path.dirname(__file__)),
+                                'ceph'))
+from ceph import CephCollector
+
+
+class CephStatsCollector(CephCollector):
     def _get_stats(self):
         """
         Get ceph stats
