@@ -71,7 +71,6 @@ class FilestatCollector(diamond.collector.Collector):
         config = super(FilestatCollector, self).get_default_config()
         config.update({
             'path':     'files',
-            'method':   'Threaded',
             'user_include': None,
             'user_exclude': None,
             'group_include': None,
@@ -90,13 +89,13 @@ class FilestatCollector(diamond.collector.Collector):
         based on the variables user_include and user_exclude
         """
     # convert user/group  lists to arrays if strings
-        if isinstance(self.config['user_include'], str):
+        if isinstance(self.config['user_include'], basestring):
             self.config['user_include'] = self.config['user_include'].split()
-        if isinstance(self.config['user_exclude'], str):
+        if isinstance(self.config['user_exclude'], basestring):
             self.config['user_exclude'] = self.config['user_exclude'].split()
-        if isinstance(self.config['group_include'], str):
+        if isinstance(self.config['group_include'], basestring):
             self.config['group_include'] = self.config['group_include'].split()
-        if isinstance(self.config['group_exclude'], str):
+        if isinstance(self.config['group_exclude'], basestring):
             self.config['group_exclude'] = self.config['group_exclude'].split()
 
         rawusers = os.popen("lsof | awk '{ print $3 }' | sort | uniq -d"
@@ -180,9 +179,9 @@ class FilestatCollector(diamond.collector.Collector):
         typelist = []
 
         # convert type list into arrays if strings
-        if isinstance(self.config['type_include'], str):
+        if isinstance(self.config['type_include'], basestring):
             self.config['type_include'] = self.config['type_include'].split()
-        if isinstance(self.config['type_exclude'], str):
+        if isinstance(self.config['type_exclude'], basestring):
             self.config['type_exclude'] = self.config['type_exclude'].split()
 
         # remove any not in include list
@@ -235,7 +234,7 @@ class FilestatCollector(diamond.collector.Collector):
             data = self.process_lsof(self.get_userlist(), self.get_typelist())
             for ukey in data.iterkeys():
                 for tkey in data[ukey].iterkeys():
-                    self.log.info('files.user.%s.%s %s' % (
+                    self.log.debug('files.user.%s.%s %s' % (
                         ukey, tkey, int(data[ukey][tkey])))
                     self.publish('user.%s.%s' % (ukey, tkey),
                                  int(data[ukey][tkey]))
