@@ -49,8 +49,6 @@ class JCollectdCollector(diamond.collector.Collector):
         config = super(JCollectdCollector, self).get_default_config()
         config.update({
             'path':     'jvm',
-            'enabled':  'False',
-            'method':   'Threaded',
             'listener_host': '127.0.0.1',
             'listener_port': 25826,
         })
@@ -95,7 +93,10 @@ class JCollectdCollector(diamond.collector.Collector):
             if suffix:
                 path = ".".join((path, suffix))
 
-        metric_type = "COUNTER" if dp.is_counter else "GAUGE"
+        if dp.is_counter:
+            metric_type = "COUNTER"
+        else:
+            metric_type = "GAUGE"
         metric = diamond.metric.Metric(path, dp.value, dp.time,
                                        metric_type=metric_type)
 
@@ -126,8 +127,11 @@ class ListenerThread(threading.Thread):
 
         try:
             while ALIVE:
-                items = rdr.interpret(poll_interval=self.poll_interval)
-                self.send_to_collector(items)
+                try:
+                    items = rdr.interpret(poll_interval=self.poll_interval)
+                    self.send_to_collector(items)
+                except ValueError, e:
+                    self.log.warn('Dropping bad packet: {0}'.format(e))
         except Exception, e:
             self.log.error('caught exception: type={0}, exc={1}'.format(type(e),
                                                                         e))
@@ -178,15 +182,27 @@ class ListenerThread(threading.Thread):
         parts.append(item.typeinstance)
 
         # construct full path, from safe parts
-        name = '.'.join([re.sub('[\. ]', '_', part) for part in parts])
+        name = '.'.join([sanitize_word(part) for part in parts])
 
-        dp = Datapoint(item.host, item.time, name,
-                       item[0][1], True if item[0][0] == 0 else False)
+        if item[0][0] == 0:
+            is_counter = True
+        else:
+            is_counter = False
+        dp = Datapoint(item.host, item.time, name, item[0][1], is_counter)
 
         return dp
 
 
-class Datapoint():
+def sanitize_word(s):
+    """Remove non-alphanumerical characters from metric word.
+    And trim excessive underscores.
+    """
+    s = re.sub('[^\w-]+', '_', s)
+    s = re.sub('__+', '_', s)
+    return s.strip('_')
+
+
+class Datapoint(object):
     def __init__(self, host, time, name, value, is_counter):
         self.host = host
         self.time = time
