@@ -8,26 +8,34 @@ values are ignored.
 
  * pymongo
 
+#### Example Configuration
+
+MongoDBCollector.conf
+
+```
+    enabled = True
+    hosts = localhost:27017, alias1@localhost:27018, etc
+```
 """
 
 import diamond.collector
 from diamond.collector import str_to_bool
 import re
+import zlib
 
 try:
     import pymongo
-    pymongo  # workaround for pyflakes issue #13
 except ImportError:
     pymongo = None
 
 try:
     from pymongo import ReadPreference
-    ReadPreference  # workaround for pyflakes issue #13
 except ImportError:
     ReadPreference = None
 
 
 class MongoDBCollector(diamond.collector.Collector):
+    MAX_CRC32 = 4294967295
 
     def __init__(self, *args, **kwargs):
         self.__totals = {}
@@ -47,11 +55,17 @@ class MongoDBCollector(diamond.collector.Collector):
             'ignore_collections': 'A regex of which collections to ignore.'
                                   ' MapReduce temporary collections (tmp.mr.*)'
                                   ' are ignored by default.',
+            'collection_sample_rate': 'Only send stats for a consistent subset '
+            'of collections. This is applied after collections are ignored via'
+            ' ignore_collections Sampling uses crc32 so it is consistent across'
+            ' replicas. Value between 0 and 1. Default is 1',
             'network_timeout': 'Timeout for mongodb connection (in seconds).'
                                ' There is no timeout by default.',
             'simple': 'Only collect the same metrics as mongostat.',
             'translate_collections': 'Translate dot (.) to underscores (_)'
-                                     ' in collection names.'
+                                     ' in collection names.',
+            'ssl': 'True to enable SSL connections to the MongoDB server.'
+                    ' Default is False'
         })
         return config_help
 
@@ -69,7 +83,9 @@ class MongoDBCollector(diamond.collector.Collector):
             'ignore_collections': '^tmp\.mr\.',
             'network_timeout': None,
             'simple': 'False',
-            'translate_collections': 'False'
+            'translate_collections': 'False',
+            'collection_sample_rate': 1,
+            'ssl': False
         })
         return config
 
@@ -80,15 +96,26 @@ class MongoDBCollector(diamond.collector.Collector):
             self.log.error('Unable to import pymongo')
             return
 
+        hosts = self.config.get('hosts')
+
+        # Convert a string config value to be an array
+        if isinstance(hosts, basestring):
+            hosts = [hosts]
+
         # we need this for backwards compatibility
         if 'host' in self.config:
-            self.config['hosts'] = [self.config['host']]
+            hosts = [self.config['host']]
 
         # convert network_timeout to integer
         if self.config['network_timeout']:
             self.config['network_timeout'] = int(
                 self.config['network_timeout'])
 
+        # convert collection_sample_rate to float
+        if self.config['collection_sample_rate']:
+            self.config['collection_sample_rate'] = float(
+                self.config['collection_sample_rate'])
+
         # use auth if given
         if 'user' in self.config:
             user = self.config['user']
@@ -100,31 +127,37 @@ class MongoDBCollector(diamond.collector.Collector):
         else:
             passwd = None
 
-        for host in self.config['hosts']:
-            if len(self.config['hosts']) == 1:
-                # one host only, no need to have a prefix
-                base_prefix = []
-            else:
-                matches = re.search('((.+)\@)?(.+)?', host)
-                alias = matches.group(2)
-                host = matches.group(3)
+        for host in hosts:
+            matches = re.search('((.+)\@)?(.+)?', host)
+            alias = matches.group(2)
+            host = matches.group(3)
 
-                if alias is None:
-                    base_prefix = [re.sub('[:\.]', '_', host)]
+            if alias is None:
+                if len(hosts) == 1:
+                    # one host only, no need to have a prefix
+                    base_prefix = []
                 else:
-                    base_prefix = [alias]
+                    base_prefix = [re.sub('[:\.]', '_', host)]
+            else:
+                base_prefix = [alias]
 
             try:
+                # Ensure that the SSL option is a boolean.
+                if type(self.config['ssl']) is str:
+                    self.config['ssl'] = str_to_bool(self.config['ssl'])
+
                 if ReadPreference is None:
                     conn = pymongo.Connection(
                         host,
                         network_timeout=self.config['network_timeout'],
+                        ssl=self.config['ssl'],
                         slave_okay=True
                     )
                 else:
                     conn = pymongo.Connection(
                         host,
                         network_timeout=self.config['network_timeout'],
+                        ssl=self.config['ssl'],
                         read_preference=ReadPreference.SECONDARY,
                     )
             except Exception, e:
@@ -148,6 +181,8 @@ class MongoDBCollector(diamond.collector.Collector):
             self._publish_dict_with_prefix(data, base_prefix)
             db_name_filter = re.compile(self.config['databases'])
             ignored_collections = re.compile(self.config['ignore_collections'])
+            sample_threshold = self.MAX_CRC32 * self.config[
+                'collection_sample_rate']
             for db_name in conn.database_names():
                 if not db_name_filter.search(db_name):
                     continue
@@ -157,6 +192,11 @@ class MongoDBCollector(diamond.collector.Collector):
                 for collection_name in conn[db_name].collection_names():
                     if ignored_collections.search(collection_name):
                         continue
+                    if (self.config['collection_sample_rate'] < 1 and (
+                            zlib.crc32(collection_name) & 0xffffffff
+                            ) > sample_threshold):
+                        continue
+
                     collection_stats = conn[db_name].command('collstats',
                                                              collection_name)
                     if str_to_bool(self.config['translate_collections']):
