@@ -6,7 +6,7 @@
 
  * Normal usage
 ```
-GRANT SELECT, REPLICATION CLIENT on *.* TO 'user'@'hostname' IDENTIFIED BY
+GRANT REPLICATION CLIENT on *.* TO 'user'@'hostname' IDENTIFIED BY
 'password';
 ```
 
@@ -36,8 +36,6 @@ import time
 try:
     import MySQLdb
     from MySQLdb import MySQLError
-    MySQLdb  # workaround for pyflakes issue #13
-    MySQLError  # workaround for pyflakes issue #13
 except ImportError:
     MySQLdb = None
     MySQLError = ValueError
@@ -223,6 +221,8 @@ class MySQLCollector(diamond.collector.Collector):
             self.innodb_status_keys[key] = re.compile(
                 self.innodb_status_keys[key])
 
+    def process_config(self):
+        super(MySQLCollector, self).process_config()
         if self.config['hosts'].__class__.__name__ != 'list':
             self.config['hosts'] = [self.config['hosts']]
 
@@ -255,6 +255,7 @@ class MySQLCollector(diamond.collector.Collector):
             'innodb': 'Collect SHOW ENGINE INNODB STATUS',
             'hosts': 'List of hosts to collect from. Format is '
             + 'yourusername:yourpassword@host:port/db[/nickname]'
+            + 'use db "None" to avoid connecting to a particular db'
         })
         return config_help
 
@@ -456,6 +457,9 @@ class MySQLCollector(diamond.collector.Collector):
             if len(nickname):
                 nickname += '.'
 
+            if params['db'] == 'None':
+                del params['db']
+
             try:
                 metrics = self.get_stats(params=params)
             except Exception, e:
