@@ -39,14 +39,12 @@ import os
 from diamond.collector import str_to_bool
 
 
-class PingCollector(diamond.collector.Collector):
+class PingCollector(diamond.collector.ProcessCollector):
 
     def get_default_config_help(self):
         config_help = super(PingCollector, self).get_default_config_help()
         config_help.update({
             'bin':         'The path to the ping binary',
-            'use_sudo':    'Use sudo?',
-            'sudo_cmd':    'Path to sudo',
         })
         return config_help
 
@@ -58,8 +56,6 @@ class PingCollector(diamond.collector.Collector):
         config.update({
             'path':             'ping',
             'bin':              '/bin/ping',
-            'use_sudo':         False,
-            'sudo_cmd':         '/usr/bin/sudo',
         })
         return config
 
@@ -69,19 +65,8 @@ class PingCollector(diamond.collector.Collector):
                 host = self.config[key]
                 metric_name = host.replace('.', '_')
 
-                if not os.access(self.config['bin'], os.X_OK):
-                    self.log.error("Path %s does not exist or is not executable"
-                                   % self.config['bin'])
-                    return
-
-                command = [self.config['bin'], '-nq', '-c 1', host]
-
-                if str_to_bool(self.config['use_sudo']):
-                    command.insert(0, self.config['sudo_cmd'])
-
-                ping = subprocess.Popen(
-                    command, stdout=subprocess.PIPE).communicate()[0].strip(
-                    ).split("\n")[-1]
+                ping = self.run_command(['-nq', '-c 1', host])
+                ping = ping[0].strip().split("\n")[-1]
 
                 # Linux
                 if ping.startswith('rtt'):
