@@ -24,9 +24,9 @@ cmdgen = None
 try:
     import pysnmp.entity.rfc3413.oneliner.cmdgen as cmdgen
     import pysnmp.debug
-    pysnmp  # workaround for pyflakes issue #13
 except ImportError:
     pysnmp = None
+    cmdgen = None
 
 warnings.showwarning = old_showwarning
 
@@ -35,20 +35,6 @@ import diamond.collector
 
 class SNMPCollector(diamond.collector.Collector):
 
-    def __init__(self, config, handlers):
-        """
-        Create a new instance of the SNMPCollector class
-        """
-        # Initialize base Class
-        diamond.collector.Collector.__init__(self, config, handlers)
-
-        # Initialize SNMP Command Generator
-        if cmdgen:
-            self.snmpCmdGen = cmdgen.CommandGenerator()
-        else:
-            self.log.error(
-                'pysnmp.entity.rfc3413.oneliner.cmdgen failed to load')
-
     def get_default_config_help(self):
         config_help = super(SNMPCollector, self).get_default_config_help()
         config_help.update({
@@ -67,28 +53,6 @@ class SNMPCollector(diamond.collector.Collector):
         # Return default config
         return default_config
 
-    def get_schedule(self):
-        """
-        Override SNMPCollector.get_schedule
-        """
-        schedule = {}
-        if 'devices' in self.config:
-            for device in self.config['devices']:
-                # Get Device Config
-                c = self.config['devices'][device]
-                # Get Task Name
-                task = "_".join([self.__class__.__name__, device])
-                # Check if task is already in schedule
-                if task in schedule:
-                    raise KeyError("Duplicate device scheduled")
-                schedule[task] = (self.collect_snmp, (device,
-                                                      c['host'],
-                                                      int(c['port']),
-                                                      c['community']),
-                                  int(self.config['splay']),
-                                  int(self.config['interval']))
-        return schedule
-
     def _convert_to_oid(self, s):
         d = s.split(".")
         return tuple([int(x) for x in d])
